@@ -1,4 +1,4 @@
-'''rlottie-python'''
-__version__ = '1.1.7'
+"""rlottie-python"""
+__version__ = "1.2.0"
 
 from .rlottie_wrapper import LottieAnimation
